exclude_precompile_calls

Function exclude_precompile_calls 

fn exclude_precompile_calls(nodes: Vec<CallTraceNode>) -> Vec<CallTraceNode>
Detaches precompile calls identified during execution from the call graph, as the tracing inspector does when configured to exclude precompile calls.

Mined transactions keep these calls for the Geth-style traces, which include them.